pub struct W(/* private fields */);Expand description
Register FM_CODE_MARGIN writer
Implementations
Sourceimpl W
impl W
Sourcepub fn margin_dcs_trim(
&mut self,
) -> FieldWriterRaw<'_, u32, FM_CODE_MARGIN_SPEC, u16, u16, Unsafe, 9, 0>
pub fn margin_dcs_trim( &mut self, ) -> FieldWriterRaw<'_, u32, FM_CODE_MARGIN_SPEC, u16, u16, Unsafe, 9, 0>
Bits 0:8 - see above table to set the DCS reference current value to be used during Margin mode. (default set to 5uS = 0x143) which gives a Margin to the Erase side. 7uA would probably be used for Margin to the PGM side
Sourcepub fn margin_dcs_trim_en(
&mut self,
) -> BitWriterRaw<'_, u32, FM_CODE_MARGIN_SPEC, bool, BitM, 9>
pub fn margin_dcs_trim_en( &mut self, ) -> BitWriterRaw<'_, u32, FM_CODE_MARGIN_SPEC, bool, BitM, 9>
Bit 9 - 0: internal device defaults used from Margin reads reference current 1: MARGIN_DCS_TRIM configuration is used during Margin read
Sourcepub fn margin_rdreg_trim(
&mut self,
) -> FieldWriterRaw<'_, u32, FM_CODE_MARGIN_SPEC, u8, u8, Unsafe, 6, 10>
pub fn margin_rdreg_trim( &mut self, ) -> FieldWriterRaw<'_, u32, FM_CODE_MARGIN_SPEC, u8, u8, Unsafe, 6, 10>
Bits 10:15 - rdreg_c trim to be used in Margin mode if enabled by MARGIN_MODE_RDREG_CHNG_EN
Sourcepub fn margin_pgm_ers_b(
&mut self,
) -> BitWriterRaw<'_, u32, FM_CODE_MARGIN_SPEC, bool, BitM, 29>
pub fn margin_pgm_ers_b( &mut self, ) -> BitWriterRaw<'_, u32, FM_CODE_MARGIN_SPEC, bool, BitM, 29>
Bit 29 - 0: ERS Margin is checked 1: PGM Margin is checked
Sourcepub fn margin_mode_rdreg_chng_en(
&mut self,
) -> BitWriterRaw<'_, u32, FM_CODE_MARGIN_SPEC, bool, BitM, 30>
pub fn margin_mode_rdreg_chng_en( &mut self, ) -> BitWriterRaw<'_, u32, FM_CODE_MARGIN_SPEC, bool, BitM, 30>
Bit 30 - when set will also use the MARGIN_RDREG_TRIM from above. Default is not to use
Sourcepub fn margin_mode_en(
&mut self,
) -> BitWriterRaw<'_, u32, FM_CODE_MARGIN_SPEC, bool, BitM, 31>
pub fn margin_mode_en( &mut self, ) -> BitWriterRaw<'_, u32, FM_CODE_MARGIN_SPEC, bool, BitM, 31>
Bit 31 - when set puts the s40ect Flash IP In Margin mode
Methods from Deref<Target = W<FM_CODE_MARGIN_SPEC>>